import React, { Fragment } from 'react'
import { get } from 'lodash'
import styled from 'styled-components'
import { shouldUpdate } from 'recompose'
import { th } from '@pubsweet/ui-toolkit'
import { DateParser } from '@pubsweet/ui'

import { Label, PersonInvitation, Text } from '../'

const ReviewersTable = ({
  invitations,
  onResendReviewerInvite,
  onRevokeReviewerInvite,
}) =>
  invitations.length > 0 && (
    <Table>
      <thead>
        <tr>
          <th>
            <Label>Full Name</Label>
          </th>
          <th>
            <Label>Invited on</Label>
          </th>
          <th>
            <Label>Responded on</Label>
          </th>
          <th>
            <Label>Submitted on</Label>
          </th>
          <th>&nbsp;</th>
        </tr>
      </thead>
      <tbody>
        {invitations.map((invitation, index) => (
          <TableRow key={invitation.id}>
            <td>
              <Text>{`${get(invitation, 'person.firstName', '')} ${get(
                invitation,
                'person.lastName',
              )}`}</Text>
              {invitation.isAccepted && (
                <Text customId ml={1}>{`Reviewer ${index + 1}`}</Text>
              )}
            </td>
            <td>
              <DateParser timestamp={invitation.invitedOn}>
                {timestamp => <Text>{timestamp}</Text>}
              </DateParser>
            </td>
            <td>
              {invitation.respondedOn && (
                <Fragment>
                  <DateParser timestamp={invitation.respondedOn}>
                    {timestamp => <Text>{timestamp}</Text>}
                  </DateParser>
                  <Text ml={1} secondary>
                    ACCEPTED
                  </Text>
                </Fragment>
              )}
            </td>
            <td>
              {invitation.respondedOn && (
                <DateParser timestamp={invitation.respondedOn}>
                  {timestamp => <Text>{timestamp}</Text>}
                </DateParser>
              )}
            </td>
            <HiddenCell>
              {!invitation.hasAnswer && (
                <PersonInvitation
                  {...invitation}
                  onResend={onResendReviewerInvite}
                  onRevoke={onRevokeReviewerInvite}
                />
              )}
            </HiddenCell>
          </TableRow>
        ))}
      </tbody>
    </Table>
  )

export default shouldUpdate(() => false)(ReviewersTable)

// #region styles
const Table = styled.table`
  border-collapse: collapse;

  & thead {
    border-bottom: 1px solid ${th('colorBorder')};
    background-color: ${th('colorBackgroundHue2')};
  }

  & th,
  & td {
    border: none;
    padding-left: calc(${th('gridUnit')} * 2);
    text-align: start;
    vertical-align: middle;

    height: calc(${th('gridUnit')} * 5);
    min-width: calc(${th('gridUnit')} * 12);
  }
`

const HiddenCell = styled.td`
  opacity: 0;
  padding-top: ${th('gridUnit')};
`

const TableRow = styled.tr`
  background-color: ${th('colorBackgroundHue2')};
  border-bottom: 1px solid ${th('colorBorder')};

  & td:first-child {
    min-width: calc(${th('gridUnit')} * 30);
  }

  &:hover {
    background-color: ${th('colorBackgroundHue3')};

    ${HiddenCell} {
      opacity: 1;
    }
  }
`
// #endregion
